@@ -15,8 +15,8 @@
 #include <CalendarSupport/CalendarSingleton>
 #include <CalendarSupport/Utils>
 
-#include <Akonadi/Calendar/IncidenceChanger>
 #include <Akonadi/Collection>
+#include <Akonadi/IncidenceChanger>
 
 #include <KCalendarCore/Calendar>
 #include <KCalendarCore/Event>
@@ -62,9 +62,7 @@ ApptSummaryWidget::ApptSummaryWidget(KOrganizerPlugin *plugin, QWidget *parent)
     configUpdated();
 }
 
-ApptSummaryWidget::~ApptSummaryWidget()
-{
-}
+ApptSummaryWidget::~ApptSummaryWidget() = default;
 
 void ApptSummaryWidget::configUpdated()
 {
@@ -230,7 +228,7 @@ void ApptSummaryWidget::viewEvent(const QString &uid)
 
 void ApptSummaryWidget::removeEvent(const Akonadi::Item &item)
 {
-    (void) mChanger->deleteIncidence(item);
+    (void)mChanger->deleteIncidence(item);
 }
 
 void ApptSummaryWidget::popupMenu(const QString &uid)
@@ -240,7 +238,7 @@ void ApptSummaryWidget::popupMenu(const QString &uid)
     // FIXME: Should say "Show Appointment" if we don't have rights to edit
     // Doesn't make sense to edit events from birthday resource for example
     QAction *editIt = popup.addAction(i18n("&Edit Appointment..."));
-
+    editIt->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
     QAction *delIt = popup.addAction(i18n("&Delete Appointment"));
     delIt->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
 
